@@ -4,12 +4,17 @@
 #' @param id A GenBank accession alphanumeric string, or a gi numeric string.
 #' @param batch_size The number of queries to submit at a time.
 #' @param key (character) NCBI Entrez API key. optional. See Details.
-#' @param ... Curl args passed on to \code{\link[crul]{HttpClient}}
-#' @details See \url{http://www.ncbi.nlm.nih.gov/Sitemap/sequenceIDs.html} for
+#' @param ... Curl args passed on to [crul::HttpClient]
+#' @details See <http://www.ncbi.nlm.nih.gov/Sitemap/sequenceIDs.html> for
 #' help on why there are two identifiers, and the difference between them.
 #' 
 #' @section Authentication:
-#' See \code{\link{taxize-authentication}} for help on authentication
+#' See [taxize-authentication] for help on authentication. We
+#' recommend getting an API key.
+#' 
+#' @section HTTP version:
+#' We hard code `http_version = 2L` to use HTTP/1.1 in HTTP requests to
+#' the Entrez API. See `curl::curl_symbols('CURL_HTTP_VERSION')` 
 #'
 #' @return one or more NCBI taxonomic IDs
 #' @examples \dontrun{
@@ -44,7 +49,8 @@ genbank2uid <- function(id, batch_size = 100, key = NULL, ...) {
     query <- tc(list(db = "nucleotide", id = paste(id, collapse = ","), api_key = key))
 
     # Execute query
-    cli <- crul::HttpClient$new(url = ncbi_base(), opts = list(...))
+    cli <- crul::HttpClient$new(url = ncbi_base(), headers = tx_ual,
+      opts = list(http_version = 2L, ...))
     res <- cli$get("entrez/eutils/esummary.fcgi", query = query)
     res$raise_for_status()
     parsed_xml <- read_xml(res$parse('UTF-8'))
@@ -62,8 +68,10 @@ genbank2uid <- function(id, batch_size = 100, key = NULL, ...) {
     if (length(raw_errors) > 0) {
       error_regexes <- c('^Invalid uid (.+) at position=[0-9]+$', 
                          '^Failed uid="(.+)"$')
-      error_ids <- lapply(error_regexes,
-                          function(r) stringr::str_match(raw_errors, r)[,2])
+      error_ids <- lapply(error_regexes, function(r) {
+        vapply(raw_errors, function(z) strexec(z, r)[[1]][2], "",
+          USE.NAMES=FALSE)
+      })
       error_ids <- unlist(error_ids)
       error_ids <- error_ids[!is.na(error_ids)]
       error_ids <- unique(error_ids)
