@@ -2,10 +2,10 @@
 #'
 #' @export
 #' @param query Vector of one or more taxonomic names (no common names)
-#' @param retrieve Specifies whether to retrieve all matches for the 
-#' names submitted. One of 'best' (retrieves only the single best match 
+#' @param retrieve Specifies whether to retrieve all matches for the
+#' names submitted. One of 'best' (retrieves only the single best match
 #' for each name submitted) or 'all' (retrieves all matches)
-#' @param ... Curl options passed on to \code{\link[crul]{verb-GET}}
+#' @param ... Curl options passed on to [crul::verb-GET]
 #' @return A data.frame
 #' @examples \dontrun{
 #' iplant_resolve(query=c("Helianthus annuus", "Homo sapiens"))
@@ -17,7 +17,7 @@ iplant_resolve <- function(query, retrieve='all', ...){
   url <- "http://tnrs.iplantc.org/tnrsm-svc/matchNames"
   query <- paste(query, collapse = ",")
   args <- tc(list(names = query, retrieve = retrieve))
-  cli <- crul::HttpClient$new(url, opts = list(...))
+  cli <- crul::HttpClient$new(url, headers = tx_ual, opts = list(...))
   out <- cli$get(query = argsnull(args))
   out$raise_for_status()
   res <- jsonlite::fromJSON(out$parse("UTF-8"), FALSE)$items
